@@ -1,18 +1,18 @@
 from ptah import form, config
-
-from base import Base
+from ptah.testing import PtahTestCase
+from pyramid.exceptions import ConfigurationConflictError
 
 
-class TestFieldset(Base):
+class TestFieldset(PtahTestCase):
+
+    _init_ptah = False
 
     def test_decl(self):
-        global MyField
-
+        @form.field('my-field')
         class MyField(form.Field):
+            pass
 
-            form.field('my-field')
-
-        self._init_ptah()
+        self.init_ptah()
         self.assertIs(form.get_field_factory('my-field'), MyField)
 
     def test_decl_register(self):
@@ -20,36 +20,34 @@ class TestFieldset(Base):
         class MyField(form.Field):
             """ """
 
-        form.register_field_factory(MyField, 'my-field')
+        form.field.register('my-field', MyField)
 
-        self._init_ptah()
+        self.init_ptah()
         self.assertIs(form.get_field_factory('my-field'), MyField)
 
     def test_decl_conflict(self):
-        global MyField, MyField2
 
+        @form.field('my-field')
         class MyField(form.Field):
+            pass
 
-            form.field('my-field')
-
-
+        @form.field('my-field')
         class MyField2(form.Field):
+            pass
 
-            form.field('my-field')
-
-        self.assertRaises(config.ConflictError, self._init_ptah)
+        self.assertRaises(ConfigurationConflictError, self.init_ptah)
 
     def test_decl_preview(self):
-        global MyField
 
+        @form.field('my-field')
         class MyField(form.Field):
-            form.field('my-field')
+            pass
 
         @form.fieldpreview(MyField)
         def preview(request):
             """ """
 
-        self._init_ptah()
+        self.init_ptah()
 
         from ptah.form.field import PREVIEW_ID
         previews = config.get_cfg_storage(PREVIEW_ID)
