@@ -7,6 +7,7 @@ from collections import OrderedDict
 from zope import interface
 from zope.interface.interface import InterfaceClass
 from pyramid.compat import configparser
+from pyramid.interfaces import PHASE1_CONFIG
 
 import ptah
 from ptah import uri, form, config
@@ -195,7 +196,8 @@ class Settings(object):
             group.update(data)
 
     def load_fromdb(self):
-        self.load(dict(ptah.get_session().query(SettingRecord.name,SettingRecord.value)))
+        self.load(dict(ptah.get_session().\
+                           query(SettingRecord.name, SettingRecord.value)))
 
     def export(self, default=False):
         groups = config.get_cfg_storage(ID_SETTINGS_GROUP).items()
@@ -330,5 +332,5 @@ class SettingRecord(ptah.get_base()):
 
     __tablename__ = 'ptah_settings'
 
-    name = sqla.Column(sqla.String, primary_key=True)
-    value = sqla.Column(sqla.String)
+    name = sqla.Column(sqla.String(128), primary_key=True)
+    value = sqla.Column(sqla.UnicodeText)
